@@ -479,7 +479,8 @@ Boolean Connected( sPSContextData *inContext )
 			
 			default:
 				// invalid error
-				return true;
+				// [3649059] err on the side of, "needs a new connection"
+				return false;
 				break;
 		}
 	}
@@ -647,7 +648,7 @@ DEBUGLOG( "for servIndex" );
 					selectTimeout.tv_sec = 10;
 					selectTimeout.tv_usec = 0;
 				}    
-				
+			
 				bzero( &cin, sizeof(cin) );
 				cin.sin_family = AF_INET;
 				cin.sin_addr.s_addr = htonl( INADDR_ANY );
@@ -702,8 +703,6 @@ DEBUGLOG( "for servIndex3" );
 			if ( servCount == 1 )
 				break;
 		}
-		
-DEBUGLOG( "out" );
 	}
 	catch( long error )
 	{
